#!/bin/sh
# IBM Confidential OCO Source Material
# 5724-J34 (C) COPYRIGHT International Business Machines Corp. 2015
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U.S. Copyright Office.
#

enteredUser=$1

wxsLoc=$( cd -P -- "$(dirname -- "$(command -v -- "$0")")" && pwd -P )
cd ${wxsLoc}/..
rootLoc=`pwd`
cd ${wxsLoc}
nannyDir="${wxsLoc}/../wlp/startscripts/nanny"

# Source environment variables
. "${wxsLoc}/exportCommons.sh"

touchWatchdogPID()
{
	# Create PID file
	touch "${nannyDir}/WATCHDOG.PID"
	chmod 666 "${nannyDir}/WATCHDOG.PID"
	chown ${enteredUser} "${nannyDir}/WATCHDOG.PID"
}

# Only work if should use systemctl or has write access to /etc
if [ ${useSystemctl} -eq 0 ] || [ -w "/etc" ]; then
	watchdogCMD="${rootLoc}/wxs/startWatchDog_nonroot.sh"
	
	# AIX register
	uname -a | grep -q 'AIX'
	if [ $? -eq 0 ]; then
		while [ "${enteredUser}" = "" ]; do
	            read enteredUser?"Please enter the user to run XSLD services under: "
	    done
	    getent passwd ${enteredUser} >> /dev/null 2>&1
	    if [ ! $? -eq 0 ]; then
	    	grep ${enteredUser} "/etc/passwd" | cut -d':' -f1 | grep -q ${enteredUser}
	    	if [ ! $? -eq 0 ]; then
		    	echo "Invalid user: ${enteredUser}"
		    	exit 1
		    fi
	    fi
	    
	    echo "Registering XSLD to ${enteredUser}"
	    
	    # Create PID file
	    touchWatchdogPID
	    
	    echo 'Adding inittab entry for XSLD.'
	    rmitab xsld_start >/dev/null 2>&1
	    mkitab "xsld_start:2:once:sudo -u ${enteredUser} ${watchdogCMD} false"
	    
	    exit $?
	fi
	
	serviceName=XS-Nanny-Watch-Dog
	
	while [ "${enteredUser}" = "" ]; do
		read -p "Please enter the user to run XSLD services under: " enteredUser
	done
	getent passwd ${enteredUser} >> /dev/null 2>&1
	if [ ! $? -eq 0 ]; then
		echo "Invalid user: ${enteredUser}"
		exit 1
	fi
	
	echo "Registering XSLD to ${enteredUser}"
	    
	# Create PID file
	touchWatchdogPID
	
	# Use systemctl if available and chkconfig isn't available
	which systemctl >/dev/null 2>&1
	useSystemctl=$?
	which chkconfig >/dev/null 2>&1
	if [ ! $? -eq 0 ] && [ ${useSystemctl} -eq 0 ]; then
	    echo 'Using systemctl to register service'
	    chmod 777 "${nannyDir}/.nannyConf"
	    
	    # Modify template file
	    initFile="${nannyDir}/${serviceName}.service"
		cp "${nannyDir}/templates/daemon.service" "${initFile}"
		sed -i "s#<<description>>#XSLD Nanny Process#g" "${initFile}"
		sed -i "s#<<envfile>>#${nannyDir}/.nannyConf#g" "${initFile}"
		sed -i "s#<<username>>#${enteredUser}#g" "${initFile}"
		sed -i "s#<<workingdir>>#${rootLoc}/wlp/usr/servers/restAdminServer#g" "${initFile}"
		sed -i "s#<<execstart>>#${watchdogCMD}#g" "${initFile}"
		
		userHome=/home/${enteredUser}
		if [ ! -e "${userHome}" ]; then
			userHome=~
		fi
		
		if [ ! -e "${userHome}/.config/systemd/user/" ]; then
			mkdir -p "${userHome}/.config/systemd/user/"
			chown ${enteredUser} "${userHome}/.config/systemd/user"
		fi
		
		chmod 666 "${initFile}"
		chown ${enteredUser} "${initFile}"
		mv "${initFile}" "${userHome}/.config/systemd/user/"
		exitCode=$?
		if [ ! "${exitCode}" = "0" ]; then
			echo 'Configuration complete'
		fi
	    exit ${exitCode}
    fi
    
    initFile="${nannyDir}/${serviceName}"
	cp "${nannyDir}/templates/nonroot-daemon.vm" "${initFile}"
	chmod +x "${initFile}"
	
	sed -i "s#\$w_name#${serviceName}#g" ${initFile}
	sed -i "s#\$w_start_cmd#${watchdogCMD} true ${enteredUser}#g" ${initFile}
	sed -i "s#\$w_stop_cmd#kill -9 \`cat ${nannyDir}/WATCHDOG.PID\` > /dev/null#g" ${initFile}
	sed -i 's#$w_status_cmd#exit 1#g' ${initFile}
	sed -i "s#<<username>>#${enteredUser}#g" "${initFile}"
	
	mv "${initFile}" /etc/init.d/${serviceName}
	
	# Use update-rc.d if available
	which update-rc.d >/dev/null 2>&1
	if [ $? -eq 0 ]; then
	    echo 'Using update-rc.d to register service'
	    update-rc.d ${serviceName} defaults
	    exitCode=$?
		if [ ! "${exitCode}" = "0" ]; then
			echo 'Configuration complete'
		fi
	    exit ${exitCode}
    else
	    # Use chkconfig if available (RHEL)
	    which chkconfig >/dev/null 2>&1
	    if [ $? -eq 0 ]; then
		    echo 'Using chkconfig to register service'
		    sed -i 's/.*Default-Start.*/\#\ chkconfig:\ 2345\ 20\ 01/' "/etc/init.d/${serviceName}"
		    chkconfig --add ${serviceName}
		    chkconfig ${serviceName} on
		    exitCode=$?
			if [ ! "${exitCode}" = "0" ]; then
				echo 'Configuration complete'
			fi
		    exit ${exitCode}
	    fi
    fi
	
else
	echo 'The current user must have write permissions to the /etc folder to register XSLD services'
	exit 1
fi
