#!/bin/sh
# IBM Confidential OCO Source Material
# 5724-J34 (C) COPYRIGHT International Business Machines Corp. 2015
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U.S. Copyright Office.
#


installDir=$( cd -P -- "$(dirname -- "$(command -v -- "$0")")" && pwd -P )/..
cd "${installDir}"
installDir=`pwd`
wxsLoc=${installDir}/wxs
cd "${wxsLoc}"

# Source environment variables
. "${wxsLoc}/exportCommons.sh"

# XS-Derby shouldn't exist in a non root installation
if [ "${zlinVersion}" = "nonroot" ] && [ -e "/etc/init.d/XS-Derby" ]; then
	echo 'XSLD was installed as root and must be started as a root user.'
	exit 1
fi

if [ "${noServiceMode}" = "true" ]; then
	cd "${installDir}/wlp/startscripts/nanny"
	
	# If can't modify inittab run as process
	cat /etc/inittab | grep -q 'startWatchDog_nonroot'
	if [ $? -eq 0 ] || [ ! -w "/etc/inittab" ]; then
		"${wxsLoc}/startWatchDog_nonroot.sh" true
		sleep 2
		watchDogPID=`ps -ef | awk '/[c]om.ibm.ws.xs.tenant.nanny.WatchDog/{print $2}'`
	else
		./setServiceAutoStart.sh true false
		
		# Wait for inittab to start Watchdog
		echo 'Waiting for inittab to start Watchdog...'
		counter=0
		watchDogPID=`ps -ef | awk '/[c]om.ibm.ws.xs.tenant.nanny.WatchDog/{print $2}'`
		while [ "${watchDogPID}" = "" ]
		do
			sleep 5
			counter=$((counter+1))
			if [ "$counter" = "20" ]; then
		  		echo 'Watchdog start not detected, cleaning up and exiting.'
		  		cd "${installDir}/wlp/startscripts/nanny"
		  		./setServiceAutoStart.sh false false
		  		
		  		# Set flag for IM in case of failure
		  		cd "${installDir}/wxs"
		  		if [ -e ".xsldStarted" ]; then
		  			rm ".xsldStarted"
		  		fi
		  		touch .xsldStartFailed
		  		
		  		exit 1
		  	fi
			
			watchDogPID=`ps -ef | awk '/[c]om.ibm.ws.xs.tenant.nanny.WatchDog/{print $2}'`
		done
	fi
	
	logFile='nanny.log'
	# In case of user install the log file is named nanny.log.0
	if [ -e "${installDir}/wlp/startscripts/nanny/log/${logFile}.0" ]; then
		logFile="${logFile}.0"
	fi
	
	if [ ! "${watchDogPID}" = "" ]; then
		echo "WatchDog started with PID ${watchDogPID}, please monitor the logs at ${installDir}/wlp/startscripts/nanny/log/${logFile}"
	else
		echo "The Watchdog process was unable to start."
	fi
	cd "${wxsLoc}"
	exit 0
elif [ ! "${zlinVersion}" = "" ]; then
	if [ ${useSystemctl} -eq 0 ]; then
		# Find the user that the service was installed under 
        serviceUser=`grep 'USER=' ~/.config/systemd/user/XS-Nanny-Watch-Dog.service | cut -d'=' -f2-`
        
		systemctl --user enable XS-Nanny-Watch-Dog.service
		systemctl --user start XS-Nanny-Watch-Dog.service
		if [ ! $? -eq 0 ]; then
            echo 'Failed to start XSLD service'
            if  [ ! "`whoami`" = "${serviceUser}" ]; then
                    echo "The current user, `whoami`, does not match the XSLD service user, ${serviceUser}"
                    echo "Please run ./startXSLD.sh as ${serviceUser}"
            fi
            exit 1
    	fi
		
	else
		/etc/init.d/XS-Nanny-Watch-Dog start
	fi
	exitCode=$?
	if [ "${exitCode}" = "0" ]; then
		logFile='nanny.log'
		# Wait a bit for service to actually start so log file is there
		# In case of user install the log file is named nanny.log.0
		sleep 2
		if [ -e "${installDir}/wlp/startscripts/nanny/log/${logFile}.0" ]; then
			logFile="${logFile}.0"
		fi
		echo "XSLD Nanny Watchdog started, please monitor the logs at ${installDir}/wlp/startscripts/nanny/log/${logFile}"
	else
		echo 'There was an error starting the XS-Nanny-Watch-Dog service'
	fi
	exit ${exitCode}
fi

echo 'Check WatchDog status. Start it if stopped'
cd "${installDir}/wlp/startscripts/nanny"
"${JAVA_CMD}" -jar wrapper.jar -qx conf/nannyWrapper.conf > /dev/null 2>&1
if [ $? -eq 3 ]; then
  "${JAVA_CMD}" -jar wrapper.jar -t conf/nannyWrapper.conf >> "${installDir}/wlp/startscripts/nanny/log/nannyInstall.log" 2>&1
fi
cd ../../../

echo "XSLD Nanny Watchdog started, please monitor the logs at ${installDir}/wlp/startscripts/nanny/log/nanny.log"
